SSO_PROVIDER_NOT_FOUND = (400, "SSO_PROVIDER_NOT_FOUND")
SSO_INVALID_STATE = (400, "SSO_INVALID_STATE")
SSO_INVALID_MODE = (400, "SSO_INVALID_MODE")
SSO_CALLBACK_ERROR = (400, "SSO_CALLBACK_ERROR")
SSO_INVALID_TOKEN = (401, "SSO_INVALID_TOKEN")
SSO_MISSING_EMAIL = (400, "SSO_MISSING_EMAIL")
SSO_USER_NOT_FOUND = (401, "SSO_USER_NOT_FOUND")
SSO_SESSION_EXPIRED = (400, "SSO_SESSION_EXPIRED")
SSO_ACCOUNT_ALREADY_LINKED = (409, "SSO_ACCOUNT_ALREADY_LINKED")
SSO_EXTERNAL_ID_CONFLICT = (409, "SSO_EXTERNAL_ID_CONFLICT")