ENABLED_USER_STATUS = "ENABLED"
DISABLED_USER_STATUS = "DISABLED"
REVOKED_USER_STATUS = "REVOKED"
DELETED_USER_STATUS = "DELETED"

MALE_GENDER = "MALE"
FEMALE_GENDER = "FEMALE"
OTHER_GENDER = "OTHER"

STATUS_CHANGE_LOG_TYPE = "STATUS_CHANGE"
ANONYMIZATION_LOG_TYPE = "ANONYMIZATION"
OBSERVATION_LOG_TYPE = "OBSERVATION"

NOT_SUPER_USER = (403, "NOT_SUPER_USER")