EMPTY_LOGIN_ERROR = (400, "EMPTY_LOGIN_ERROR")
EMPTY_PASSWORD_ERROR = (400, "EMPTY_PASSWORD_ERROR")
WEAK_PASSWORD = (400, "WEAK_PASSWORD")
INVALID_NAME = (400, "INVALID_NAME")
INVALID_GENDER = (400, "INVALID_GENDER")
INVALID_LANGUAGE = (400, "INVALID_LANGUAGE")
INVALID_RESET_TOKEN_ERROR = (400, "INVALID_RESET_TOKEN_ERROR")
EXPIRED_RESET_TOKEN_ERROR = (400, "EXPIRED_RESET_TOKEN_ERROR")
EMAIL_ALREADY_VALIDATED_ERROR = (400, "EMAIL_ALREADY_VALIDATED_ERROR")
INVALID_STATUS_CHANGE = (400, "INVALID_STATUS_CHANGE")
INVALID_USER_STATUS = (400, "INVALID_USER_STATUS")
INVALID_USER_ID = (400, "INVALID_USER_ID")
USER_ALREADY_ANONYMIZED = (400, "USER_ALREADY_ANONYMIZED")
ACCESS_DENIED_ERROR = (401, "ACCESS_DENIED_ERROR")
INVALID_REFRESH_TOKEN_ERROR = (401, "INVALID_REFRESH_TOKEN_ERROR")
MISSING_REFRESH_TOKEN_ERROR = (401, "MISSING_REFRESH_TOKEN_ERROR")
INVALID_CREDENTIALS_ERROR = (401, "INVALID_CREDENTIALS_ERROR")
WRONG_REFRESH_TOKEN_ERROR = (401, "WRONG_REFRESH_TOKEN_ERROR")
BLOCKED_USER_ERROR = (403, "BLOCKED_USER_ERROR")
INVALID_XSRF_TOKEN_ERROR = (403, "INVALID_XSRF_TOKEN_ERROR")
ALREADY_CONNECTED_ERROR = (403, "ALREADY_CONNECTED_ERROR")
USER_ALREADY_EXISTS = (409, "USER_ALREADY_EXISTS")
RATE_LIMIT_ERROR = (429, "RATE_LIMIT_ERROR")


